@@ -1,16 +1,16 @@
 from __future__ import print_function
 from __future__ import absolute_import
 
-from builtins import range
-import os
+from pathlib import Path
 import shutil
+from tqdm import tqdm
 from traits.api import HasTraits, Str, Float, Int, List, Bool
 
 import yaml
 
 # Temporary path for parameters (active run will be copied here)
-par_dir_prefix = "parameters"
-max_cam = 4
+par_dir_prefix = str("parameters")
+max_cam = int(4)
 
 
 def g(f):
@@ -23,12 +23,12 @@ def g(f):
 
 class Parameters(HasTraits):
     # default path of the directory of the param files
-    default_path = "parameters"
+    default_path = Path("parameters")
 
-    def __init__(self, path=default_path):
+    def __init__(self, path: Path=default_path):
         HasTraits.__init__(self)
-        self.path = path
-        self.exp_path = os.path.dirname(self.path)
+        self.path = path.resolve()
+        self.exp_path = self.path.parent 
 
     # returns the name of the specific params file
     def filename(self):
@@ -36,7 +36,7 @@ class Parameters(HasTraits):
 
     # returns the path to the specific params file
     def filepath(self):
-        return os.path.join(self.path, self.filename())
+        return self.path.joinpath(self.filename())
 
     # sets all variables of the param file (no actual writing to disk)
     def set(self, *vars):
@@ -71,17 +71,17 @@ class Parameters(HasTraits):
 
     def istherefile(self, filename):
         """checks if the filename exists in the experimental path"""
-        if not os.path.isfile(os.path.join(self.exp_path, filename)):
-            warning("%s not found" % filename)
+        if not self.exp_path.joinpath(filename).is_file():
+            warning(f"{filename} not found")
 
 
 # Print detailed error to the console and show the user a friendly error window
 def error(owner, msg):
-    print("Exception caught, message: %s" % (msg))
+    print(f"Exception caught, message: {msg}")
 
 
 def warning(msg):
-    print("Warning message: %s" % (msg))
+    print(f"Warning message: {msg}")
 
 
 # Reads a parameters directory and returns a dictionary with all parameter
@@ -117,19 +117,34 @@ def readParamsDir(par_path):
     return ret
 
 
-def copy_params_dir(src, dest):
-    ext_set = (".dat", ".par", ".yaml")
-    files = [f for f in os.listdir(src) if f.endswith(ext_set)]
+def copy_params_dir(src: Path, dest: Path):
+    """ Copying all parameter files from /src folder to /dest 
+        including .dat, .par and .yaml files
+    """
+    ext_set = ("*.dat", "*.par", "*.yaml")
+    files = []
+    for ext in ext_set:
+        files.extend(src.glob(ext))
+        
+    # print(f'List of parameter files in {src} is \n {files} \n')    
+    # print(f'Destination folder is {dest.resolve()}')
+    # files = [f for f in src.iterdir() if str(f.parts[-1]).endswith(ext_set)]    
 
-    if not os.path.exists(dest):
-        os.mkdir(dest)
-    print("copy from %s to %s" % (src, dest))
-    for f in files:
+    if not dest.is_dir():
+        print(f"Destination folder does not exist, creating it")
+        dest.mkdir(parents=True, exist_ok=True)
+
+    print(f"Copying now file by file from {src} to {dest}: \n")
+
+    for f in tqdm(files):
+        # print(f"From {f} to {dest / f.name} ")
         shutil.copyfile(
-            os.path.abspath(os.path.join(src, f)),
-            os.path.abspath(os.path.join(dest, f)),
+            f,
+            dest / f.name,
         )
 
+    print(f"Successfully \n")
+
 
 # Specific parameter classes #######
 
@@ -235,7 +250,7 @@ class PtvParams(Parameters):
         return "ptv.par"
 
     def read(self):
-        if not os.path.isfile(self.filepath()):
+        if not self.filepath().exists():
             warning(f"{self.filepath()} does not exist ")
         try:
             with open(self.filepath(), "r", encoding="utf8") as f:
@@ -1212,7 +1227,7 @@ class ExamineParams(Parameters):
         return "examine.par"
 
     def read(self):
-        if os.path.exists(self.filepath()) is False:
+        if not self.filepath().exists():
             f = open(self.filepath(), "w")
             f.write("%d\n" % 0)
             f.write("%d\n" % 0)
@@ -1309,7 +1324,7 @@ class DumbbellParams(Parameters):
         return "dumbbell.par"
 
     def read(self):
-        if os.path.exists(self.filepath()) is False:
+        if not self.filepath().exists():
             f = open(self.filepath(), "w")
             f.write("%f\n" % 0.0)
             f.write("%f\n" % 0.0)
@@ -1404,7 +1419,7 @@ class ShakingParams(Parameters):
         return "shaking.par"
 
     def read(self):
-        if os.path.exists(self.filepath()) is False:
+        if not self.filepath().exists():
             f = open(self.filepath(), "w")
             f.write("%f\n" % 0)
             f.write("%f\n" % 0)
@@ -1473,8 +1488,8 @@ class MultiPlaneParams(Parameters):
                 self.n_planes = int(g(f))
                 for i in range(self.n_planes):
                     self.plane_name.append(g(f))
-                    if not os.path.isfile(self.plane_name[i]):
-                        print("plane %s is missing." % self.plane_name[i])
+                    if not self.plane_name[i].is_file():
+                        print(f"Plane {self.plane_name[i]} is missing.")
 
         except BaseException:
             error(None, "%s not found" % self.filepath())
